pecos.error\_models.error\_model\_abc
=====================================

.. automodule:: pecos.error_models.error_model_abc











   .. rubric:: Classes

   .. autosummary::

      ErrorModel
